.. _askbot.migrations:

:mod:`askbot.migrations`
=================

.. automodule:: askbot.migrations
    :members:
    :undoc-members:
    :show-inheritance:

.. _modules::

:mod:`Modules`
-------


* :ref:`askbot.migrations.0001_initial`
* :ref:`askbot.migrations.0002_auto__add_field_answer_text__chg_field_answer_html__add_field_question`
* :ref:`askbot.migrations.0003_copy_denorm_text_record_to_posts_for_fulltext_search`
* :ref:`askbot.migrations.0004_install_full_text_indexes_for_mysql`
* :ref:`askbot.migrations.0005_install_badges`
* :ref:`askbot.migrations.0006_add_subscription_setting_for_comments_and_mentions`
* :ref:`askbot.migrations.0007_install_mentions_model`
* :ref:`askbot.migrations.0008_add_html_field_to_comments`
* :ref:`askbot.migrations.0009_calculate_html_field_for_comments`
* :ref:`askbot.migrations.0010_add_receiving_user_to_activity_model`
* :ref:`askbot.migrations.0011_merge_mentions_into_activity`
* :ref:`askbot.migrations.0012_delete_some_unused_models`
* :ref:`askbot.migrations.0013_add_response_count__to_user`
* :ref:`askbot.migrations.0014_rename_schema_from_forum_to_askbot`
* :ref:`askbot.migrations.0015_rename_forum_contenttypes_to_askbot`
* :ref:`askbot.migrations.0016_auto__del_validationhash`
* :ref:`askbot.migrations.0017_add_group__moderators`

